==> upload-api-client-internal-2.55.0.tgz: package/src/models/UploadJsParams.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { SingleParameterFunction } from "./SingleParameterFunction";

/**
 * The *optional* 2nd parameter given to the ```upload.uploadFile(file, params)``` method from the Upload JavaScript SDK.
 */
export type UploadJsParams = {
  /**
   * An arbitrary JSON object to store against the uploaded file as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * Callback taking a single parameter: an object of type UploadJsBeginEvent.
   *
   * Fired once the upload starts.
   */
  onBegin?: SingleParameterFunction;
  /**
   * Callback taking a single parameter: an object of type UploadJsProgressEvent.
   *
   * Fired multiple a times a second (regardless of network-level activity) to yield progress values that are smoothed using an exponential moving average (EMA).
   */
  onProgress?: SingleParameterFunction;
  /**
   * The path to upload the file to.
   */
  path?: FilePathDefinition;
  /**
   * The tags you specify here determine which rules will be executed for the file upload.
   *
   * You create rules in the Upload Dashboard, and choose which tags trigger each rule.
   *
   * Rules include: max file size checks, traffic limit checks, rate limit checks, etc.
   */
  tags?: Array<FileTagName>;
};

==> upload-api-client-internal-2.64.0.tgz: package/src/models/UploadJsParams.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { SingleParameterFunction } from "./SingleParameterFunction";

/**
 * The *optional* 2nd parameter given to the ```upload.uploadFile(file, params)``` method from the Upload JavaScript SDK.
 */
export type UploadJsParams = {
  /**
   * Arbitrary JSON to store against the uploaded file as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * Callback taking a single parameter: an object of type UploadJsBeginEvent.
   *
   * Fired once the upload starts.
   */
  onBegin?: SingleParameterFunction;
  /**
   * Callback taking a single parameter: an object of type UploadJsProgressEvent.
   *
   * Fired multiple a times a second (regardless of network-level activity) to yield progress values that are smoothed using an exponential moving average (EMA).
   */
  onProgress?: SingleParameterFunction;
  /**
   * The path to upload the file to.
   */
  path?: FilePathDefinition;
  /**
   * The tags you specify here determine which rules will be executed for the file upload.
   *
   * You create rules in the Upload Dashboard, and choose which tags trigger each rule.
   *
   * Rules include: max file size checks, traffic limit checks, rate limit checks, etc.
   */
  tags?: Array<FileTagName>;
};
